DebateJudgeConfig

Struct DebateJudgeConfig 

pub struct DebateJudgeConfig {
    pub min_rounds_before_stop: u32,
}
Configuration for the optional judge that assesses each debate round.

The judge is a separate LLM call that reads the full round transcript and decides whether consensus has been reached or whether the debate should continue for more rounds. When no judge is configured all DebateConfig::rounds are always executed.

Fields

min_rounds_before_stop: u32

The judge will not attempt early stopping before this round index (1-based). 1 means the judge may recommend a stop after the very first round. Defaults to 1.